@@ -6,3 +6,8 @@ class DownloadError(Exception):
 class ChecksumError(Exception):
     """ Raises when the downloaded file checksum is not correct.
     """
+
+
+class InvalidTrackerError(Exception):
+    """ Raises when unknown tracker requested .
+    """
